@@ -886,7 +886,6 @@ static PyObject *xc_reset()
 /* Get a netlist						*/
 /*--------------------------------------------------------------*/
 
-extern u_int subindex;  /* count for labeling spice subcircuits */
 extern PyObject *pyglobals(objectptr);
 extern PyObject *pytoplevel(objectptr);
 
@@ -899,7 +898,6 @@ static PyObject *xc_netlist()
       return NULL;
    }
 
-   subindex = 1;
    rdict = PyDict_New();
    PyDict_SetItem(rdict, PyString_FromString("globals"), pyglobals(topobject));
    PyDict_SetItem(rdict, PyString_FromString("circuit"), pytoplevel(topobject));
@@ -1565,7 +1563,7 @@ static PyObject *xc_library(PyObject *self, PyObject *args)
    }
 
    if (libnum >= xobjs.numlibs || libnum < 0)
-      libnum = createlibrary();
+      libnum = createlibrary(FALSE);
    else
       libnum += LIBRARY - 1;
 
